# Binary Operations

## Morphological Operations
::: fdtdx.constraints.binary_transform.dilate_jax
::: fdtdx.constraints.binary_transform.erode_jax
::: fdtdx.constraints.binary_transform.seperated_3d_dilation
::: fdtdx.constraints.binary_transform.binary_median_filter

## Connectivity Analysis
::: fdtdx.constraints.binary_transform.compute_polymer_connection
::: fdtdx.constraints.binary_transform.compute_air_connection
::: fdtdx.constraints.binary_transform.connect_slice

## Structure Optimization
::: fdtdx.constraints.binary_transform.remove_floating_polymer
::: fdtdx.constraints.binary_transform.remove_polymer_non_connected_to_x_max_middle
::: fdtdx.constraints.binary_transform.connect_holes_and_structures
